@@ -133,6 +133,8 @@ static NPIdentifier error_id;
 static NPIdentifier status_id;
 static NPIdentifier URL_id;
 static NPIdentifier versionInfo_id;
+static NPIdentifier enabled_id;
+static NPIdentifier enableContextMenu_id;
 static NPIdentifier controls_currentPosition_id;
 static NPIdentifier controls_currentItem_id;
 static NPIdentifier media_duration_id;
@@ -246,7 +248,7 @@ tv_driver(NULL), tv_device(NULL), tv_input(NULL), tv_width(0), tv_height(0)
     identifier = NPN_GetStringIdentifier("href");
     // Get the location property from the location object.
     b = NPN_GetProperty(mInstance, locationObj, identifier, &variantValue);
-#ifdef HAVE_NEW_XULRUNNER
+#ifdef NPAPI_USE_UPPERCASE_UTF8
     page_url = g_strdup_printf("%s", NPVARIANT_TO_STRING(variantValue).UTF8Characters);
 #else
     page_url = g_strdup_printf("%s", NPVARIANT_TO_STRING(variantValue).utf8characters);
@@ -321,6 +323,8 @@ tv_driver(NULL), tv_device(NULL), tv_input(NULL), tv_width(0), tv_height(0)
     status_id = NPN_GetStringIdentifier("status");
     URL_id = NPN_GetStringIdentifier("URL");
     versionInfo_id = NPN_GetStringIdentifier("versionInfo");
+    enabled_id = NPN_GetStringIdentifier("enabled");
+    enableContextMenu_id = NPN_GetStringIdentifier("enableContextMenu");
     controls_currentPosition_id = NPN_GetStringIdentifier("currentPosition");
     media_duration_id = NPN_GetStringIdentifier("duration");
     settings_volume_id = NPN_GetStringIdentifier("volume");
@@ -970,13 +974,13 @@ int32 CPlugin::Write(NPStream * stream, int32 offset, int32 len, void *buffer)
         }
         if (!item->opened) {
             if ((item->localsize >= (cache_size * 1024)) && (percent >= 0.2)) {
-                printf("Setting to play because %i > %i\n", item->localsize, cache_size * 1024);
+                // printf("Setting to play because %i > %i\n", item->localsize, cache_size * 1024);
                 ok_to_play = TRUE;
             }
             if (ok_to_play == FALSE && (item->localsize > (cache_size * 2 * 1024))
                 && (cache_size >= 512)) {
-                printf("Setting to play because %i > %i (double cache)\n", item->localsize,
-                       cache_size * 2 * 1024);
+                // printf("Setting to play because %i > %i (double cache)\n", item->localsize,
+                //        cache_size * 2 * 1024);
                 ok_to_play = TRUE;
             }
             if (ok_to_play == FALSE) {
@@ -987,8 +991,8 @@ int32 CPlugin::Write(NPStream * stream, int32 offset, int32 len, void *buffer)
                 }
                 if (item->bitrate > 0) {
                     if (item->localsize / item->bitrate >= 10 && (percent >= 0.2)) {
-                        printf("Setting to play becuase %i >= 10\n",
-                               item->localsize / item->bitrate);
+                        // printf("Setting to play because %i >= 10\n",
+                        //        item->localsize / item->bitrate);
                         ok_to_play = TRUE;
                         if (post_dom_events && this->id != NULL) {
                             postDOMEvent(mInstance, this->id, "qt_canplay");
@@ -1386,45 +1390,44 @@ int progress_callback(void *clientp, double dltotal, double dlnow, double ultota
                 item->lastsize = item->localsize;
             }
         }
-
         // Disable playing of partially cached apple.com files, mplayer seems to crash on these files
         /*
-        if (!item->opened) {
-            if ((item->localsize >= (plugin->cache_size * 1024)) && (percent >= 0.2)) {
-                //printf("Setting to play because %i > %i\n", item->localsize,
-                //       plugin->cache_size * 1024);
-                ok_to_play = TRUE;
-            }
-            if (ok_to_play == FALSE && (item->localsize > (plugin->cache_size * 2 * 1024))
-                && (plugin->cache_size >= 512)) {
-                //printf("Setting to play because %i > %i (double cache)\n", item->localsize,
-                //       plugin->cache_size * 2 * 1024);
-                ok_to_play = TRUE;
-            }
-            if (ok_to_play == FALSE) {
-                if (item->bitrate == 0 && item->bitrate_requests < 5
-                    && ((gint) (percent * 100) > item->bitrate_requests)) {
-                    //item->bitrate = request_bitrate(plugin, item, item->local);
-                    item->bitrate_requests++;
-                }
-                if (item->bitrate > 0) {
-                    if (item->localsize / item->bitrate >= 10 && (percent >= 0.2)) {
-                        printf("Setting to play becuase %i >= 10\n",
-                               item->localsize / item->bitrate);
-                        ok_to_play = TRUE;
-                        if (plugin->post_dom_events && plugin->id != NULL) {
-                            postDOMEvent(plugin->mInstance, plugin->id, "qt_canplay");
-                        }
-                    }
-                }
-            }
+           if (!item->opened) {
+           if ((item->localsize >= (plugin->cache_size * 1024)) && (percent >= 0.2)) {
+           //printf("Setting to play because %i > %i\n", item->localsize,
+           //       plugin->cache_size * 1024);
+           ok_to_play = TRUE;
+           }
+           if (ok_to_play == FALSE && (item->localsize > (plugin->cache_size * 2 * 1024))
+           && (plugin->cache_size >= 512)) {
+           //printf("Setting to play because %i > %i (double cache)\n", item->localsize,
+           //       plugin->cache_size * 2 * 1024);
+           ok_to_play = TRUE;
+           }
+           if (ok_to_play == FALSE) {
+           if (item->bitrate == 0 && item->bitrate_requests < 5
+           && ((gint) (percent * 100) > item->bitrate_requests)) {
+           //item->bitrate = request_bitrate(plugin, item, item->local);
+           item->bitrate_requests++;
+           }
+           if (item->bitrate > 0) {
+           if (item->localsize / item->bitrate >= 10 && (percent >= 0.2)) {
+           printf("Setting to play becuase %i >= 10\n",
+           item->localsize / item->bitrate);
+           ok_to_play = TRUE;
+           if (plugin->post_dom_events && plugin->id != NULL) {
+           postDOMEvent(plugin->mInstance, plugin->id, "qt_canplay");
+           }
+           }
+           }
+           }
+
+           }
+         */
 
-        }
-        */
-        
         // try downloading entire file
         ok_to_play = FALSE;
-        
+
         // if not opened, over cache level and not an href target then try and open it
         if ((!item->opened) && ok_to_play == TRUE) {
             id = item->controlid;
@@ -1987,7 +1990,7 @@ bool ScriptablePluginObjectMedia::Invoke(NPIdentifier name, const NPVariant * ar
     }
 
     if (name == media_getItemInfo_id) {
-#ifdef HAVE_NEW_XULRUNNER
+#ifdef NPAPI_USE_UPPERCASE_UTF8
         arg = g_strdup(NPVARIANT_TO_STRING(args[0]).UTF8Characters);
 #else
         arg = g_strdup(NPVARIANT_TO_STRING(args[0]).utf8characters);
@@ -2399,7 +2402,7 @@ bool ScriptablePluginObject::Invoke(NPIdentifier name, const NPVariant * args,
     }
 
     if (name == Open_id || name == SetFileName_id || name == SetHREF_id || name == SetURL_id) {
-#ifdef HAVE_NEW_XULRUNNER
+#ifdef NPAPI_USE_UPPERCASE_UTF8
         pPlugin->SetFilename(NPVARIANT_TO_STRING(args[0]).UTF8Characters);
 #else
         pPlugin->SetFilename(NPVARIANT_TO_STRING(args[0]).utf8characters);
@@ -2486,7 +2489,7 @@ bool ScriptablePluginObject::Invoke(NPIdentifier name, const NPVariant * args,
     }
 
     if (name == onClick_id) {
-#ifdef HAVE_NEW_XULRUNNER
+#ifdef NPAPI_USE_UPPERCASE_UTF8
         pPlugin->SetOnClick(NPVARIANT_TO_STRING(args[0]).UTF8Characters);
 #else
         pPlugin->SetOnClick(NPVARIANT_TO_STRING(args[0]).utf8characters);
@@ -2495,7 +2498,7 @@ bool ScriptablePluginObject::Invoke(NPIdentifier name, const NPVariant * args,
     }
 
     if (name == onMediaComplete_id) {
-#ifdef HAVE_NEW_XULRUNNER
+#ifdef NPAPI_USE_UPPERCASE_UTF8
         pPlugin->SetOnMediaComplete(NPVARIANT_TO_STRING(args[0]).UTF8Characters);
 #else
         pPlugin->SetOnMediaComplete(NPVARIANT_TO_STRING(args[0]).utf8characters);
@@ -2504,7 +2507,7 @@ bool ScriptablePluginObject::Invoke(NPIdentifier name, const NPVariant * args,
     }
 
     if (name == onMouseUp_id) {
-#ifdef HAVE_NEW_XULRUNNER
+#ifdef NPAPI_USE_UPPERCASE_UTF8
         pPlugin->SetOnMouseUp(NPVARIANT_TO_STRING(args[0]).UTF8Characters);
 #else
         pPlugin->SetOnMouseUp(NPVARIANT_TO_STRING(args[0]).utf8characters);
@@ -2513,7 +2516,7 @@ bool ScriptablePluginObject::Invoke(NPIdentifier name, const NPVariant * args,
     }
 
     if (name == onMouseDown_id) {
-#ifdef HAVE_NEW_XULRUNNER
+#ifdef NPAPI_USE_UPPERCASE_UTF8
         pPlugin->SetOnMouseDown(NPVARIANT_TO_STRING(args[0]).UTF8Characters);
 #else
         pPlugin->SetOnMouseDown(NPVARIANT_TO_STRING(args[0]).utf8characters);
@@ -2522,7 +2525,7 @@ bool ScriptablePluginObject::Invoke(NPIdentifier name, const NPVariant * args,
     }
 
     if (name == onMouseOut_id) {
-#ifdef HAVE_NEW_XULRUNNER
+#ifdef NPAPI_USE_UPPERCASE_UTF8
         pPlugin->SetOnMouseOut(NPVARIANT_TO_STRING(args[0]).UTF8Characters);
 #else
         pPlugin->SetOnMouseOut(NPVARIANT_TO_STRING(args[0]).utf8characters);
@@ -2531,7 +2534,7 @@ bool ScriptablePluginObject::Invoke(NPIdentifier name, const NPVariant * args,
     }
 
     if (name == onMouseOver_id) {
-#ifdef HAVE_NEW_XULRUNNER
+#ifdef NPAPI_USE_UPPERCASE_UTF8
         pPlugin->SetOnMouseOver(NPVARIANT_TO_STRING(args[0]).UTF8Characters);
 #else
         pPlugin->SetOnMouseOver(NPVARIANT_TO_STRING(args[0]).utf8characters);
@@ -2540,7 +2543,7 @@ bool ScriptablePluginObject::Invoke(NPIdentifier name, const NPVariant * args,
     }
 
     if (name == onDestroy_id) {
-#ifdef HAVE_NEW_XULRUNNER
+#ifdef NPAPI_USE_UPPERCASE_UTF8
         pPlugin->SetOnDestroy(NPVARIANT_TO_STRING(args[0]).UTF8Characters);
 #else
         pPlugin->SetOnDestroy(NPVARIANT_TO_STRING(args[0]).utf8characters);
@@ -2572,7 +2575,10 @@ bool ScriptablePluginObject::HasProperty(NPIdentifier name)
         || name == URL_id
         || name == versionInfo_id
         || name == status_id
-        || name == controls_id || name == media_id || name == settings_id || name == error_id) {
+        || name == controls_id
+        || name == media_id
+        || name == settings_id
+        || name == error_id || name == enabled_id || name == enableContextMenu_id) {
         return true;
     } else {
         return false;
@@ -2596,8 +2602,11 @@ bool ScriptablePluginObject::GetProperty(NPIdentifier name, NPVariant * result)
 
     if (name == filename_id || name == src_id || name == URL_id) {
         pPlugin->GetFilename(&filename);
-        if (filename != NULL)
+        if (filename != NULL) {
             STRINGZ_TO_NPVARIANT(filename, *result);
+        } else {
+            STRINGZ_TO_NPVARIANT(strdup(""), *result);
+        }            
         return true;
     }
 
@@ -2657,6 +2666,16 @@ bool ScriptablePluginObject::GetProperty(NPIdentifier name, NPVariant * result)
         return true;
     }
 
+    if (name == enabled_id) {
+        BOOLEAN_TO_NPVARIANT(true, *result);
+        return true;
+    }
+
+    if (name == enableContextMenu_id) {
+        BOOLEAN_TO_NPVARIANT(!(pPlugin->disable_context_menu), *result);
+        return true;
+    }
+
     if (name == controls_id) {
         OBJECT_TO_NPVARIANT(pPlugin->GetScriptableObjectControls(), *result);
         return true;
@@ -2690,7 +2709,7 @@ bool ScriptablePluginObject::SetProperty(NPIdentifier name, const NPVariant * va
     }
 
     if (name == filename_id || name == src_id || name == URL_id) {
-#ifdef HAVE_NEW_XULRUNNER
+#ifdef NPAPI_USE_UPPERCASE_UTF8
         pPlugin->SetFilename(NPVARIANT_TO_STRING(*value).UTF8Characters);
 #else
         pPlugin->SetFilename(NPVARIANT_TO_STRING(*value).utf8characters);
@@ -2717,6 +2736,15 @@ bool ScriptablePluginObject::SetProperty(NPIdentifier name, const NPVariant * va
         return true;
     }
 
+    if (name == enabled_id) {
+        return true;
+    }
+
+    if (name == enableContextMenu_id) {
+        pPlugin->disable_context_menu = !(NPVARIANT_TO_BOOLEAN(*value));
+        return true;
+    }
+
     return false;
 }
 
